summaryrefslogtreecommitdiffstats
path: root/chromium/chrome/browser/resources/settings/about_page/about_page_browser_proxy.js
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2017-11-20 10:33:36 +0100
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2017-11-22 11:45:12 +0000
commitbe59a35641616a4cf23c4a13fa0632624b021c1b (patch)
tree9da183258bdf9cc413f7562079d25ace6955467f /chromium/chrome/browser/resources/settings/about_page/about_page_browser_proxy.js
parentd702e4b6a64574e97fc7df8fe3238cde70242080 (diff)
BASELINE: Update Chromium to 62.0.3202.101
Change-Id: I2d5eca8117600df6d331f6166ab24d943d9814ac Reviewed-by: Alexandru Croitor <alexandru.croitor@qt.io>
Diffstat (limited to 'chromium/chrome/browser/resources/settings/about_page/about_page_browser_proxy.js')
-rw-r--r--chromium/chrome/browser/resources/settings/about_page/about_page_browser_proxy.js8
1 files changed, 6 insertions, 2 deletions
diff --git a/chromium/chrome/browser/resources/settings/about_page/about_page_browser_proxy.js b/chromium/chrome/browser/resources/settings/about_page/about_page_browser_proxy.js
index beb4b67e2ec..df85fd8c99e 100644
--- a/chromium/chrome/browser/resources/settings/about_page/about_page_browser_proxy.js
+++ b/chromium/chrome/browser/resources/settings/about_page/about_page_browser_proxy.js
@@ -18,8 +18,8 @@ var RegulatoryInfo;
/**
* @typedef {{
* currentChannel: string,
* targetChannel: string,
* canChangeChannel: boolean,
* }}
*/
@@ -48,6 +48,7 @@ var AboutPageUpdateInfo;
*/
var BrowserChannel = {
BETA: 'beta-channel',
+ CANARY: 'canary-channel',
DEV: 'dev-channel',
STABLE: 'stable-channel',
};
@@ -102,6 +103,8 @@ cr.define('settings', function() {
switch (channel) {
case BrowserChannel.BETA:
return 'aboutChannelBeta';
+ case BrowserChannel.CANARY:
+ return 'aboutChannelCanary';
case BrowserChannel.DEV:
return 'aboutChannelDev';
case BrowserChannel.STABLE:
@@ -120,6 +123,7 @@ cr.define('settings', function() {
function isTargetChannelMoreStable(currentChannel, targetChannel) {
// List of channels in increasing stability order.
var channelList = [
+ BrowserChannel.CANARY,
BrowserChannel.DEV,
BrowserChannel.BETA,
BrowserChannel.STABLE,
@@ -18,8 +18,8 @@ var RegulatoryInfo;
/**
* @typedef {{
- * currentChannel: string,
- * targetChannel: string,
+ * currentChannel: BrowserChannel,
+ * targetChannel: BrowserChannel,
* canChangeChannel: boolean,
* }}